var test = require('tape');
var React = require('react');
var ReactTestUtils = require('react-addons-test-utils');
var Styletron = require('styletron-server');

var connectToStyles = require('../connect-to-styles');
var Provider = require('../provider');

test('provider provides instance', function (t) {
  var mockInstance = {};
  var MockComponent = function (props, context) {
    t.equal(context.styletron, mockInstance, 'styletron instance override provided');
    return React.createElement('div');
  };
  MockComponent.contextTypes = {styletron: React.PropTypes.object};
  ReactTestUtils.renderIntoDocument(React.createElement(Provider, {
    styletron: mockInstance
  }, React.createElement(MockComponent)));
  t.end();
});

test('connectToStyles works', function (t) {
  t.plan(3);
  var expectedProps = {prop1: 'red'};
  var hoc = connectToStyles(function (props) {
    t.deepEqual(props, expectedProps, 'props accessible in hoc');
    return {style1: {color: 'red'}};
  });
  var MockComponent = function (props) {
    t.deepEqual(props.styles, {style1: ' c0'}, 'style props passed');
    return React.createElement('div');
  }
  var Wrapped = hoc(MockComponent);
  var styletron = new Styletron();
  var output = ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(Wrapped, expectedProps))
  );
  t.equal(styletron.getCss(), '.c0{color:red}');
});
